@@ -7,10 +7,10 @@ private_key_path = "#{test_path}/private_key.pem"
 
 key = OpenSSL::PKey::RSA.new File.read private_key_path
 
-cipher = OpenSSL::Cipher.new 'DES-CBC'
+cipher = OpenSSL::Cipher.new 'AES-256-CBC'
 
 encrypted_key_path = "#{test_path}/encrypted_private_key.pem"
 
-open encrypted_key_path, 'w' do |io|
+File.open encrypted_key_path, 'w' do |io|
   io.write key.to_pem cipher, 'Foo bar'
 end
