@@ -18,29 +18,30 @@ open 'lib/rubygems/util/licenses.rb', 'w' do |io|
 require 'rubygems/text'
 
 class Gem::Licenses
-
   extend Gem::Text
 
   NONSTANDARD = 'Nonstandard'.freeze
+  LICENSE_REF = 'LicenseRef-.+'.freeze
 
   # Software Package Data Exchange (SPDX) standard open-source software
   # license identifiers
-  LICENSE_IDENTIFIERS = %w(
+  LICENSE_IDENTIFIERS = %w[
     #{licenses.sort.join "\n    "}
-  ).freeze
+  ].freeze
 
   # exception identifiers
-  EXCEPTION_IDENTIFIERS = %w(
+  EXCEPTION_IDENTIFIERS = %w[
     #{exceptions.sort.join "\n    "}
-  ).freeze
+  ].freeze
 
   REGEXP = %r{
     \\A
-    (
+    (?:
       \#{Regexp.union(LICENSE_IDENTIFIERS)}
       \\+?
-      (\\s WITH \\s \#{Regexp.union(EXCEPTION_IDENTIFIERS)})?
+      (?:\\s WITH \\s \#{Regexp.union(EXCEPTION_IDENTIFIERS)})?
       | \#{NONSTANDARD}
+      | \#{LICENSE_REF}
     )
     \\Z
   }ox.freeze
@@ -57,7 +58,6 @@ class Gem::Licenses
     return unless lowest < license.size
     by_distance[lowest]
   end
-
 end
   RUBY
 end
